export * from '@solana/accounts';
import { Address } from '@solana/addresses';
export * from '@solana/addresses';
export * from '@solana/codecs';
export * from '@solana/errors';
export * from '@solana/functional';
import * as _solana_instructions from '@solana/instructions';
import { IInstruction } from '@solana/instructions';
export * from '@solana/instructions';
export * from '@solana/keys';
export * from '@solana/programs';
import { createSolanaRpc } from '@solana/rpc';
export * from '@solana/rpc';
export * from '@solana/rpc-parsed-types';
import { createSolanaRpcSubscriptions } from '@solana/rpc-subscriptions';
export * from '@solana/rpc-subscriptions';
import { DevnetUrl, MainnetUrl, TestnetUrl, Blockhash } from '@solana/rpc-types';
export * from '@solana/rpc-types';
import { TransactionSigner } from '@solana/signers';
export * from '@solana/signers';
import * as _solana_transaction_messages from '@solana/transaction-messages';
import { TransactionVersion } from '@solana/transaction-messages';
export * from '@solana/transaction-messages';
export * from '@solana/transactions';
export { RpcRequest, RpcRequestTransformer, RpcResponse, RpcResponseData, RpcResponseTransformer, createRpcMessage } from '@solana/rpc-spec-types';

/** Solana cluster moniker */
type SolanaClusterMoniker = "mainnet-beta" | "devnet" | "testnet" | "localnet";
type GenericUrl = string & {};
type ModifiedClusterUrl = DevnetUrl | MainnetUrl | TestnetUrl | GenericUrl;
type SolanaUrlOrMoniker = SolanaClusterMoniker | ModifiedClusterUrl;
type CreateSolanaClientArgs = {
    /** Full RPC URL (for a private RPC endpoint) or the Solana moniker (for a public RPC endpoint) */
    urlOrMoniker: URL | SolanaUrlOrMoniker;
    /** Configuration used to create the `rpc` client */
    rpcConfig?: Parameters<typeof createSolanaRpc>[1];
    /** Configuration used to create the `rpcSubscriptions` client */
    rpcSubscriptionsConfig?: Parameters<typeof createSolanaRpcSubscriptions>[1];
};
type CreateSolanaClientResult = {
    /** Newly created Solana RPC client  */
    rpc: ReturnType<typeof createSolanaRpc>;
    /** Newly created Solana RPC subscriptions client */
    rpcSubscriptions: ReturnType<typeof createSolanaRpcSubscriptions>;
};

type ExplorerLinkAccount = {
    address: string;
};
type ExplorerLinkTransaction = {
    transaction: string;
};
type ExplorerLinkBlock = {
    block: string;
};
/**
 * @param cluster - Default: `mainnet-beta`
 */
type GetExplorerLinkArgs = {
    cluster?: SolanaUrlOrMoniker;
} & (ExplorerLinkAccount | ExplorerLinkTransaction | ExplorerLinkBlock);

type Prettify<T> = {
    [K in keyof T]: T[K];
} & {};

/** 1 billion lamports SOL */
declare const LAMPORTS_PER_SOL = 1000000000;

/**
 * Get a public Solana RPC endpoint for a cluster based on its moniker
 *
 * Note: These RPC URLs are rate limited and not suitable for production applications.
 */
declare function getPublicSolanaRpcUrl(cluster: SolanaClusterMoniker): string;
/**
 * Create a Solana `rpc` and `rpcSubscriptions` client
 */
declare function createSolanaClient({ urlOrMoniker, rpcConfig, rpcSubscriptionsConfig, }: CreateSolanaClientArgs): CreateSolanaClientResult;

/**
 * Craft a Solana Explorer link on any cluster
 */
declare function getExplorerLink(props: GetExplorerLinkArgs): URL;

type CreateTransactionInput = {
    /**
     * Transaction version
     * - `legacy` is commonly used
     * - `0` is needed for use with Address Lookup Tables
     * */
    version: TransactionVersion;
    /** List of instructions for this transaction */
    instructions: IInstruction[];
    /** Address or Signer that will pay transaction fees */
    feePayer: Address | TransactionSigner;
    /**
     * Latest blockhash (aka transaction lifetime) for this transaction to
     * accepted for execution on the Solana network
     * */
    latestBlockhash?: Readonly<{
        blockhash: Blockhash;
        lastValidBlockHeight: bigint;
    }>;
};

/**
 * Simple interface for creating a Solana transaction
 */
declare function createTransaction({ version, feePayer, instructions, latestBlockhash, }: CreateTransactionInput): _solana_transaction_messages.ITransactionMessageWithFeePayer<string> & Omit<Readonly<{
    instructions: readonly _solana_instructions.IInstruction<string, readonly _solana_instructions.IAccountMeta<string>[]>[];
    version: "legacy";
}> | Readonly<{
    instructions: readonly _solana_instructions.IInstruction<string, readonly (_solana_instructions.IAccountLookupMeta<string, string> | _solana_instructions.IAccountMeta<string>)[]>[];
    version: 0;
}>, "feePayer">;

/**
 * Calculate the total rent needed for to create an account, with or without extra data stored in it
 */
declare function getMinimumBalanceForRentExemption(space?: bigint | number): bigint;

export { type CreateSolanaClientArgs, type CreateSolanaClientResult, type GetExplorerLinkArgs, LAMPORTS_PER_SOL, type ModifiedClusterUrl, type Prettify, type SolanaClusterMoniker, type SolanaUrlOrMoniker, createSolanaClient, createTransaction, getExplorerLink, getMinimumBalanceForRentExemption, getPublicSolanaRpcUrl };
